@@ -20,4 +20,6 @@
 export { getMetricOffsetsMap } from './getMetricOffsetsMap';
 export { isTimeComparison } from './isTimeComparison';
 export { isDerivedSeries } from './isDerivedSeries';
+export { extractExtraMetrics } from './extractExtraMetrics';
+export { getOriginalSeries, hasTimeOffset } from './timeOffset';
 export { TIME_COMPARISON_SEPARATOR } from './constants';
