@@ -30,7 +30,10 @@ import {
 import { PivotTableQueryFormData } from '../types';
 
 export default function buildQuery(formData: PivotTableQueryFormData) {
-  const { groupbyColumns = [], groupbyRows = [] } = formData;
+  const { groupbyColumns = [], groupbyRows = [], extra_form_data } = formData;
+  const time_grain_sqla =
+    extra_form_data?.time_grain_sqla || formData.time_grain_sqla;
+
   // TODO: add deduping of AdhocColumns
   const columns = Array.from(
     new Set([
@@ -40,12 +43,16 @@ export default function buildQuery(formData: PivotTableQueryFormData) {
   ).map(col => {
     if (
       isPhysicalColumn(col) &&
-      formData.time_grain_sqla &&
+      time_grain_sqla &&
       hasGenericChartAxes &&
-      formData?.temporal_columns_lookup?.[col]
+      /* Charts created before `GENERIC_CHART_AXES` is enabled have a different
+       * form data, with `granularity_sqla` set instead.
+       */
+      (formData?.temporal_columns_lookup?.[col] ||
+        formData.granularity_sqla === col)
     ) {
       return {
-        timeGrain: formData.time_grain_sqla,
+        timeGrain: time_grain_sqla,
         columnType: 'BASE_AXIS',
         sqlExpression: col,
         label: col,
