@@ -21,7 +21,8 @@ import React from 'react';
 import { render, screen } from 'spec/helpers/testing-library';
 import userEvent from '@testing-library/user-event';
 import ErrorMessageWithStackTrace from './ErrorMessageWithStackTrace';
-import { ErrorLevel, ErrorSource } from './types';
+import BasicErrorAlert from './BasicErrorAlert';
+import { ErrorLevel, ErrorSource, ErrorTypeEnum } from './types';
 
 jest.mock(
   'src/components/Icons/Icon',
@@ -57,3 +58,21 @@ test('should render the link', () => {
   expect(link).toHaveTextContent('(Request Access)');
   expect(link).toHaveAttribute('href', mockedProps.link);
 });
+
+test('should render the fallback', () => {
+  const body = 'Blahblah';
+  render(
+    <ErrorMessageWithStackTrace
+      error={{
+        error_type: ErrorTypeEnum.FRONTEND_NETWORK_ERROR,
+        message: body,
+        extra: {},
+        level: 'error',
+      }}
+      fallback={<BasicErrorAlert title="Blah" body={body} level="error" />}
+      {...mockedProps}
+    />,
+    { useRedux: true },
+  );
+  expect(screen.getByText(body)).toBeInTheDocument();
+});
