@@ -18,11 +18,14 @@
  */
 /* eslint camelcase: 0 */
 import { ActionCreators as UndoActionCreators } from 'redux-undo';
+import rison from 'rison';
 import {
   ensureIsArray,
-  t,
-  SupersetClient,
+  isFeatureEnabled,
+  FeatureFlag,
   getSharedLabelColor,
+  SupersetClient,
+  t,
 } from '@superset-ui/core';
 import {
   addChart,
@@ -36,7 +39,10 @@ import {
   SAVE_TYPE_OVERWRITE,
   SAVE_TYPE_OVERWRITE_CONFIRMED,
 } from 'src/dashboard/util/constants';
-import { isCrossFiltersEnabled } from 'src/dashboard/util/crossFilters';
+import {
+  getCrossFiltersConfiguration,
+  isCrossFiltersEnabled,
+} from 'src/dashboard/util/crossFilters';
 import {
   addSuccessToast,
   addWarningToast,
@@ -46,14 +52,13 @@ import serializeActiveFilterValues from 'src/dashboard/util/serializeActiveFilte
 import serializeFilterScopes from 'src/dashboard/util/serializeFilterScopes';
 import { getActiveFilters } from 'src/dashboard/util/activeDashboardFilters';
 import { safeStringify } from 'src/utils/safeStringify';
-import { FeatureFlag, isFeatureEnabled } from 'src/featureFlags';
 import { logEvent } from 'src/logger/actions';
 import { LOG_ACTIONS_CONFIRM_OVERWRITE_DASHBOARD_METADATA } from 'src/logger/LogUtils';
 import { UPDATE_COMPONENTS_PARENTS_LIST } from './dashboardLayout';
 import {
-  setChartConfiguration,
+  saveChartConfiguration,
   dashboardInfoChanged,
-  SET_CHART_CONFIG_COMPLETE,
+  SAVE_CHART_CONFIG_COMPLETE,
 } from './dashboardInfo';
 import { fetchDatasourceMetadata } from './datasources';
 import {
@@ -79,20 +84,18 @@ export function removeSlice(sliceId) {
   return { type: REMOVE_SLICE, sliceId };
 }
 
-const FAVESTAR_BASE_URL = '/superset/favstar/Dashboard';
 export const TOGGLE_FAVE_STAR = 'TOGGLE_FAVE_STAR';
 export function toggleFaveStar(isStarred) {
   return { type: TOGGLE_FAVE_STAR, isStarred };
 }
 
-export const FETCH_FAVE_STAR = 'FETCH_FAVE_STAR';
 export function fetchFaveStar(id) {
   return function fetchFaveStarThunk(dispatch) {
     return SupersetClient.get({
-      endpoint: `${FAVESTAR_BASE_URL}/${id}/count/`,
+      endpoint: `/api/v1/dashboard/favorite_status/?q=${rison.encode([id])}`,
     })
       .then(({ json }) => {
-        if (json.count > 0) dispatch(toggleFaveStar(true));
+        dispatch(toggleFaveStar(!!json?.result?.[0]?.value));
       })
       .catch(() =>
         dispatch(
@@ -106,13 +109,16 @@ export function fetchFaveStar(id) {
   };
 }
 
-export const SAVE_FAVE_STAR = 'SAVE_FAVE_STAR';
 export function saveFaveStar(id, isStarred) {
   return function saveFaveStarThunk(dispatch) {
-    const urlSuffix = isStarred ? 'unselect' : 'select';
-    return SupersetClient.get({
-      endpoint: `${FAVESTAR_BASE_URL}/${id}/${urlSuffix}/`,
-    })
+    const endpoint = `/api/v1/dashboard/${id}/favorites/`;
+    const apiCall = isStarred
+      ? SupersetClient.delete({
+          endpoint,
+        })
+      : SupersetClient.post({ endpoint });
+
+    return apiCall
       .then(() => {
         dispatch(toggleFaveStar(!isStarred));
       })
@@ -277,35 +283,31 @@ export function saveDashboardRequest(data, id, saveType) {
 
     const handleChartConfiguration = () => {
       const {
-        dashboardInfo: {
-          metadata: { chart_configuration = {} },
-        },
+        dashboardLayout,
+        charts,
+        dashboardInfo: { metadata },
       } = getState();
-      const chartConfiguration = Object.values(chart_configuration).reduce(
-        (prev, next) => {
-          // If chart removed from dashboard - remove it from metadata
-          if (
-            Object.values(layout).find(
-              layoutItem => layoutItem?.meta?.chartId === next.id,
-            )
-          ) {
-            return { ...prev, [next.id]: next };
-          }
-          return prev;
-        },
-        {},
+      return getCrossFiltersConfiguration(
+        dashboardLayout.present,
+        metadata,
+        charts,
       );
-      return chartConfiguration;
     };
 
     const onCopySuccess = response => {
-      const lastModifiedTime = response.json.last_modified_time;
+      const lastModifiedTime = response.json.result.last_modified_time;
       if (lastModifiedTime) {
         dispatch(saveDashboardRequestSuccess(lastModifiedTime));
       }
       if (isFeatureEnabled(FeatureFlag.DASHBOARD_CROSS_FILTERS)) {
-        const chartConfiguration = handleChartConfiguration();
-        dispatch(setChartConfiguration(chartConfiguration));
+        const { chartConfiguration, globalChartConfiguration } =
+          handleChartConfiguration();
+        dispatch(
+          saveChartConfiguration({
+            chartConfiguration,
+            globalChartConfiguration,
+          }),
+        );
       }
       dispatch(saveDashboardFinished());
       dispatch(addSuccessToast(t('This dashboard was saved successfully.')));
@@ -325,7 +327,7 @@ export function saveDashboardRequest(data, id, saveType) {
         );
         if (metadata.chart_configuration) {
           dispatch({
-            type: SET_CHART_CONFIG_COMPLETE,
+            type: SAVE_CHART_CONFIG_COMPLETE,
             chartConfiguration: metadata.chart_configuration,
           });
         }
@@ -373,8 +375,10 @@ export function saveDashboardRequest(data, id, saveType) {
       [SAVE_TYPE_OVERWRITE, SAVE_TYPE_OVERWRITE_CONFIRMED].includes(saveType)
     ) {
       let chartConfiguration = {};
+      let globalChartConfiguration = {};
       if (isFeatureEnabled(FeatureFlag.DASHBOARD_CROSS_FILTERS)) {
-        chartConfiguration = handleChartConfiguration();
+        ({ chartConfiguration, globalChartConfiguration } =
+          handleChartConfiguration());
       }
       const updatedDashboard =
         saveType === SAVE_TYPE_OVERWRITE_CONFIRMED
@@ -392,6 +396,7 @@ export function saveDashboardRequest(data, id, saveType) {
                 default_filters: safeStringify(serializedFilters),
                 filter_scopes: serializedFilterScopes,
                 chart_configuration: chartConfiguration,
+                global_chart_configuration: globalChartConfiguration,
               }),
             };
 
@@ -450,24 +455,21 @@ export function saveDashboardRequest(data, id, saveType) {
         });
     }
     // changing the data as the endpoint requires
-    const copyData = { ...cleanedData };
-    if (copyData.metadata) {
-      delete copyData.metadata;
+    if ('positions' in cleanedData && !('positions' in cleanedData.metadata)) {
+      cleanedData.metadata.positions = cleanedData.positions;
     }
-    const finalCopyData = {
-      ...copyData,
-      // the endpoint is expecting the metadata to be flat
-      ...(cleanedData?.metadata || {}),
+    cleanedData.metadata.default_filters = safeStringify(serializedFilters);
+    cleanedData.metadata.filter_scopes = serializedFilterScopes;
+    const copyPayload = {
+      dashboard_title: cleanedData.dashboard_title,
+      css: cleanedData.css,
+      duplicate_slices: cleanedData.duplicate_slices,
+      json_metadata: JSON.stringify(cleanedData.metadata),
     };
+
     return SupersetClient.post({
-      endpoint: `/superset/copy_dash/${id}/`,
-      postPayload: {
-        data: {
-          ...finalCopyData,
-          default_filters: safeStringify(serializedFilters),
-          filter_scopes: safeStringify(serializedFilterScopes),
-        },
-      },
+      endpoint: `/api/v1/dashboard/${id}/copy/`,
+      jsonPayload: copyPayload,
     })
       .then(response => onCopySuccess(response))
       .catch(response => onError(response));
@@ -604,13 +606,6 @@ export function setColorScheme(colorScheme) {
   return { type: SET_COLOR_SCHEME, colorScheme };
 }
 
-export function setColorSchemeAndUnsavedChanges(colorScheme) {
-  return dispatch => {
-    dispatch(setColorScheme(colorScheme));
-    dispatch(setUnsavedChanges(true));
-  };
-}
-
 export const SET_DIRECT_PATH = 'SET_DIRECT_PATH';
 export function setDirectPathToChild(path) {
   return { type: SET_DIRECT_PATH, path };
