@@ -18,9 +18,13 @@
  */
 import React from 'react';
 import PropTypes from 'prop-types';
-
-import { SupersetClient, t } from '@superset-ui/core';
-
+import { isEmpty } from 'lodash';
+import {
+  isFeatureEnabled,
+  FeatureFlag,
+  SupersetClient,
+  t,
+} from '@superset-ui/core';
 import { Menu } from 'src/components/Menu';
 import { URL_PARAMS } from 'src/constants';
 import ShareMenuItems from 'src/dashboard/components/menu/ShareMenuItems';
@@ -35,7 +39,6 @@ import downloadAsImage from 'src/utils/downloadAsImage';
 import getDashboardUrl from 'src/dashboard/util/getDashboardUrl';
 import { getActiveFilters } from 'src/dashboard/util/activeDashboardFilters';
 import { getUrlParam } from 'src/utils/urlUtils';
-import { FILTER_BOX_MIGRATION_STATES } from 'src/explore/constants';
 import { LOG_ACTIONS_DASHBOARD_DOWNLOAD_AS_IMAGE } from 'src/logger/LogUtils';
 
 const propTypes = {
@@ -70,11 +73,6 @@ const propTypes = {
   refreshLimit: PropTypes.number,
   refreshWarning: PropTypes.string,
   lastModifiedTime: PropTypes.number.isRequired,
-  filterboxMigrationState: PropTypes.oneOf(
-    Object.keys(FILTER_BOX_MIGRATION_STATES).map(
-      key => FILTER_BOX_MIGRATION_STATES[key],
-    ),
-  ),
 };
 
 const defaultProps = {
@@ -82,7 +80,6 @@ const defaultProps = {
   colorScheme: undefined,
   refreshLimit: 0,
   refreshWarning: null,
-  filterboxMigrationState: FILTER_BOX_MIGRATION_STATES.NOOP,
 };
 
 const MENU_KEYS = {
@@ -230,7 +227,6 @@ class HeaderActionsDropdown extends React.PureComponent {
       lastModifiedTime,
       addSuccessToast,
       addDangerToast,
-      filterboxMigrationState,
       setIsDropdownVisible,
       isDropdownVisible,
       ...rest
@@ -379,7 +375,10 @@ class HeaderActionsDropdown extends React.PureComponent {
           )
         ) : null}
         {editMode &&
-          filterboxMigrationState !== FILTER_BOX_MIGRATION_STATES.CONVERTED && (
+          !(
+            isFeatureEnabled(FeatureFlag.DASHBOARD_NATIVE_FILTERS) &&
+            isEmpty(dashboardInfo?.metadata?.filter_scopes)
+          ) && (
             <Menu.Item key={MENU_KEYS.SET_FILTER_MAPPING}>
               <FilterScopeModal
                 className="m-r-5"
