@@ -24,6 +24,7 @@ import {
   DataMask,
   DataMaskStateWithId,
   DataMaskWithId,
+  isFeatureEnabled,
   FeatureFlag,
   Filter,
   FilterConfiguration,
@@ -31,7 +32,6 @@ import {
 } from '@superset-ui/core';
 import { NATIVE_FILTER_PREFIX } from 'src/dashboard/components/nativeFilters/FiltersConfigModal/utils';
 import { HYDRATE_DASHBOARD } from 'src/dashboard/actions/hydrate';
-import { isFeatureEnabled } from 'src/featureFlags';
 import {
   AnyDataMaskAction,
   CLEAR_DATA_MASK_STATE,
@@ -56,6 +56,7 @@ export function getInitialDataMask(
   }
   return {
     ...otherProps,
+    __cache: {},
     extraFormData: {},
     filterState: {},
     ownState: {},
