@@ -40,9 +40,11 @@ beforeAll(() => {
     result: [{ label: 'Chart A', value: 'a' }],
   });
 
-  fetchMock.get('glob:*/superset/user_slices*', [
-    { id: 'a', title: 'Chart A', viz_type: 'table', data: {} },
-  ]);
+  fetchMock.get('glob:*/api/v1/chart/*', {
+    result: [
+      { id: 'a', slice_name: 'Chart A', viz_type: 'table', form_data: {} },
+    ],
+  });
 
   setupColors();
 
