@@ -23,6 +23,7 @@
 
 import { QueryFormData } from '@superset-ui/core';
 import Owner from './Owner';
+import Tag from './TagType';
 
 export type ChartLinkedDashboard = {
   id: number;
@@ -44,6 +45,7 @@ export interface Chart {
   cache_timeout: number | null;
   thumbnail_url?: string;
   owners?: Owner[];
+  tags?: Tag[];
   last_saved_at?: string;
   last_saved_by?: {
     id: number;
