@@ -57,23 +57,47 @@ def validate_json(value: Union[bytes, bytearray, str]) -> None:
 
 class AnnotationPostSchema(Schema):
     short_descr = fields.String(
-        description=annotation_short_descr, allow_none=False, validate=[Length(1, 500)]
+        metadata={"description": annotation_short_descr},
+        required=True,
+        allow_none=False,
+        validate=[Length(1, 500)],
+    )
+    long_descr = fields.String(
+        metadata={"description": annotation_long_descr}, allow_none=True
+    )
+    start_dttm = fields.DateTime(
+        metadata={"description": annotation_start_dttm},
+        required=True,
+        allow_none=False,
+    )
+    end_dttm = fields.DateTime(
+        metadata={"description": annotation_end_dttm}, required=True, allow_none=False
     )
-    long_descr = fields.String(description=annotation_long_descr, allow_none=True)
-    start_dttm = fields.DateTime(description=annotation_start_dttm, allow_none=False)
-    end_dttm = fields.DateTime(description=annotation_end_dttm, allow_none=False)
     json_metadata = fields.String(
-        description=annotation_json_metadata, validate=validate_json, allow_none=True,
+        metadata={"description": annotation_json_metadata},
+        validate=validate_json,
+        allow_none=True,
     )
 
 
 class AnnotationPutSchema(Schema):
     short_descr = fields.String(
-        description=annotation_short_descr, required=False, validate=[Length(1, 500)]
+        metadata={"description": annotation_short_descr},
+        required=False,
+        validate=[Length(1, 500)],
+    )
+    long_descr = fields.String(
+        metadata={"description": annotation_long_descr}, required=False, allow_none=True
+    )
+    start_dttm = fields.DateTime(
+        metadata={"description": annotation_start_dttm}, required=False
+    )
+    end_dttm = fields.DateTime(
+        metadata={"description": annotation_end_dttm}, required=False
     )
-    long_descr = fields.String(description=annotation_long_descr, required=False)
-    start_dttm = fields.DateTime(description=annotation_start_dttm, required=False)
-    end_dttm = fields.DateTime(description=annotation_end_dttm, required=False)
     json_metadata = fields.String(
-        description=annotation_json_metadata, validate=validate_json, required=False
+        metadata={"description": annotation_json_metadata},
+        validate=validate_json,
+        required=False,
+        allow_none=True,
     )
