@@ -16,7 +16,7 @@
 # under the License.
 import json
 import logging
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 from flask_appbuilder.models.sqla import Model
 from marshmallow import ValidationError
@@ -24,7 +24,8 @@ from marshmallow import ValidationError
 from superset import security_manager
 from superset.commands.base import BaseCommand, UpdateMixin
 from superset.commands.utils import populate_roles
-from superset.dao.exceptions import DAOUpdateFailedError
+from superset.daos.dashboard import DashboardDAO
+from superset.daos.exceptions import DAOUpdateFailedError
 from superset.dashboards.commands.exceptions import (
     DashboardForbiddenError,
     DashboardInvalidError,
@@ -32,7 +33,6 @@ from superset.dashboards.commands.exceptions import (
     DashboardSlugExistsValidationError,
     DashboardUpdateFailedError,
 )
-from superset.dashboards.dao import DashboardDAO
 from superset.exceptions import SupersetSecurityException
 from superset.extensions import db
 from superset.models.dashboard import Dashboard
@@ -41,13 +41,15 @@ logger = logging.getLogger(__name__)
 
 
 class UpdateDashboardCommand(UpdateMixin, BaseCommand):
-    def __init__(self, model_id: int, data: Dict[str, Any]):
+    def __init__(self, model_id: int, data: dict[str, Any]):
         self._model_id = model_id
         self._properties = data.copy()
         self._model: Optional[Dashboard] = None
 
     def run(self) -> Model:
         self.validate()
+        assert self._model
+
         try:
             dashboard = DashboardDAO.update(self._model, self._properties, commit=False)
             if self._properties.get("json_metadata"):
@@ -56,6 +58,7 @@ class UpdateDashboardCommand(UpdateMixin, BaseCommand):
                     data=json.loads(self._properties.get("json_metadata", "{}")),
                     commit=False,
                 )
+            dashboard = DashboardDAO.update_charts_owners(dashboard, commit=False)
             db.session.commit()
         except DAOUpdateFailedError as ex:
             logger.exception(ex.exception)
@@ -63,9 +66,9 @@ class UpdateDashboardCommand(UpdateMixin, BaseCommand):
         return dashboard
 
     def validate(self) -> None:
-        exceptions: List[ValidationError] = []
-        owners_ids: Optional[List[int]] = self._properties.get("owners")
-        roles_ids: Optional[List[int]] = self._properties.get("roles")
+        exceptions: list[ValidationError] = []
+        owners_ids: Optional[list[int]] = self._properties.get("owners")
+        roles_ids: Optional[list[int]] = self._properties.get("roles")
         slug: Optional[str] = self._properties.get("slug")
 
         # Validate/populate model exists
@@ -91,9 +94,7 @@ class UpdateDashboardCommand(UpdateMixin, BaseCommand):
         except ValidationError as ex:
             exceptions.append(ex)
         if exceptions:
-            exception = DashboardInvalidError()
-            exception.add_list(exceptions)
-            raise exception
+            raise DashboardInvalidError(exceptions=exceptions)
 
         # Validate/Populate role
         if roles_ids is None:
@@ -104,6 +105,4 @@ class UpdateDashboardCommand(UpdateMixin, BaseCommand):
         except ValidationError as ex:
             exceptions.append(ex)
         if exceptions:
-            exception = DashboardInvalidError()
-            exception.add_list(exceptions)
-            raise exception
+            raise DashboardInvalidError(exceptions=exceptions)
