@@ -18,16 +18,18 @@
 
 import json
 import logging
-from typing import Iterator, Tuple
+from collections.abc import Iterator
 
 import yaml
 
 from superset.commands.export.models import ExportModelsCommand
 from superset.connectors.sqla.models import SqlaTable
+from superset.daos.database import DatabaseDAO
 from superset.datasets.commands.exceptions import DatasetNotFoundError
-from superset.datasets.dao import DatasetDAO
+from superset.daos.dataset import DatasetDAO
 from superset.utils.dict_import_export import EXPORT_VERSION
 from superset.utils.file import get_filename
+from superset.utils.ssh_tunnel import mask_password_info
 
 logger = logging.getLogger(__name__)
 
@@ -35,14 +37,13 @@ JSON_KEYS = {"params", "template_params", "extra"}
 
 
 class ExportDatasetsCommand(ExportModelsCommand):
-
     dao = DatasetDAO
     not_found = DatasetNotFoundError
 
     @staticmethod
     def _export(
         model: SqlaTable, export_related: bool = True
-    ) -> Iterator[Tuple[str, str]]:
+    ) -> Iterator[tuple[str, str]]:
         db_file_name = get_filename(
             model.database.database_name, model.database.id, skip_id=True
         )
@@ -97,6 +98,15 @@ class ExportDatasetsCommand(ExportModelsCommand):
                 except json.decoder.JSONDecodeError:
                     logger.info("Unable to decode `extra` field: %s", payload["extra"])
 
+            if ssh_tunnel := DatabaseDAO.get_ssh_tunnel(model.database.id):
+                ssh_tunnel_payload = ssh_tunnel.export_to_dict(
+                    recursive=False,
+                    include_parent_ref=False,
+                    include_defaults=True,
+                    export_uuids=False,
+                )
+                payload["ssh_tunnel"] = mask_password_info(ssh_tunnel_payload)
+
             payload["version"] = EXPORT_VERSION
 
             file_content = yaml.safe_dump(payload, sort_keys=False)
