@@ -14,8 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+import json
 import logging
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Optional, Union
 from urllib import request
 from urllib.error import URLError
 
@@ -36,22 +37,20 @@ logger = get_task_logger(__name__)
 logger.setLevel(logging.INFO)
 
 
-def get_url(chart: Slice, dashboard: Optional[Dashboard] = None) -> str:
-    """Return external URL for warming up a given chart/table cache."""
-    with app.test_request_context():
-        baseurl = "{WEBDRIVER_BASEURL}".format(**app.config)
-        url = f"{baseurl}superset/warm_up_cache/?slice_id={chart.id}"
-        if dashboard:
-            url += f"&dashboard_id={dashboard.id}"
-        return url
+def get_payload(chart: Slice, dashboard: Optional[Dashboard] = None) -> dict[str, int]:
+    """Return payload for warming up a given chart/table cache."""
+    payload = {"chart_id": chart.id}
+    if dashboard:
+        payload["dashboard_id"] = dashboard.id
+    return payload
 
 
 class Strategy:  # pylint: disable=too-few-public-methods
     """
     A cache warm up strategy.
 
-    Each strategy defines a `get_urls` method that returns a list of URLs to
-    be fetched from the `/superset/warm_up_cache/` endpoint.
+    Each strategy defines a `get_payloads` method that returns a list of payloads to
+    send to the `/api/v1/chart/warm_up_cache` endpoint.
 
     Strategies can be configured in `superset/config.py`:
 
@@ -72,8 +71,8 @@ class Strategy:  # pylint: disable=too-few-public-methods
     def __init__(self) -> None:
         pass
 
-    def get_urls(self) -> List[str]:
-        raise NotImplementedError("Subclasses must implement get_urls!")
+    def get_payloads(self) -> list[dict[str, int]]:
+        raise NotImplementedError("Subclasses must implement get_payloads!")
 
 
 class DummyStrategy(Strategy):  # pylint: disable=too-few-public-methods
@@ -94,11 +93,15 @@ class DummyStrategy(Strategy):  # pylint: disable=too-few-public-methods
 
     name = "dummy"
 
-    def get_urls(self) -> List[str]:
+    def get_payloads(self) -> list[dict[str, int]]:
         session = db.create_scoped_session()
-        charts = session.query(Slice).all()
 
-        return [get_url(chart) for chart in charts]
+        try:
+            charts = session.query(Slice).all()
+        finally:
+            session.close()
+
+        return [get_payload(chart) for chart in charts]
 
 
 class TopNDashboardsStrategy(Strategy):  # pylint: disable=too-few-public-methods
@@ -126,25 +129,29 @@ class TopNDashboardsStrategy(Strategy):  # pylint: disable=too-few-public-method
         self.top_n = top_n
         self.since = parse_human_datetime(since) if since else None
 
-    def get_urls(self) -> List[str]:
-        urls = []
+    def get_payloads(self) -> list[dict[str, int]]:
+        payloads = []
         session = db.create_scoped_session()
 
-        records = (
-            session.query(Log.dashboard_id, func.count(Log.dashboard_id))
-            .filter(and_(Log.dashboard_id.isnot(None), Log.dttm >= self.since))
-            .group_by(Log.dashboard_id)
-            .order_by(func.count(Log.dashboard_id).desc())
-            .limit(self.top_n)
-            .all()
-        )
-        dash_ids = [record.dashboard_id for record in records]
-        dashboards = session.query(Dashboard).filter(Dashboard.id.in_(dash_ids)).all()
-        for dashboard in dashboards:
-            for chart in dashboard.slices:
-                urls.append(get_url(chart, dashboard))
-
-        return urls
+        try:
+            records = (
+                session.query(Log.dashboard_id, func.count(Log.dashboard_id))
+                .filter(and_(Log.dashboard_id.isnot(None), Log.dttm >= self.since))
+                .group_by(Log.dashboard_id)
+                .order_by(func.count(Log.dashboard_id).desc())
+                .limit(self.top_n)
+                .all()
+            )
+            dash_ids = [record.dashboard_id for record in records]
+            dashboards = (
+                session.query(Dashboard).filter(Dashboard.id.in_(dash_ids)).all()
+            )
+            for dashboard in dashboards:
+                for chart in dashboard.slices:
+                    payloads.append(get_payload(chart, dashboard))
+        finally:
+            session.close()
+        return payloads
 
 
 class DashboardTagsStrategy(Strategy):  # pylint: disable=too-few-public-methods
@@ -165,84 +172,99 @@ class DashboardTagsStrategy(Strategy):  # pylint: disable=too-few-public-methods
 
     name = "dashboard_tags"
 
-    def __init__(self, tags: Optional[List[str]] = None) -> None:
+    def __init__(self, tags: Optional[list[str]] = None) -> None:
         super().__init__()
         self.tags = tags or []
 
-    def get_urls(self) -> List[str]:
-        urls = []
+    def get_payloads(self) -> list[dict[str, int]]:
+        payloads = []
         session = db.create_scoped_session()
 
-        tags = session.query(Tag).filter(Tag.name.in_(self.tags)).all()
-        tag_ids = [tag.id for tag in tags]
+        try:
+            tags = session.query(Tag).filter(Tag.name.in_(self.tags)).all()
+            tag_ids = [tag.id for tag in tags]
 
-        # add dashboards that are tagged
-        tagged_objects = (
-            session.query(TaggedObject)
-            .filter(
-                and_(
-                    TaggedObject.object_type == "dashboard",
-                    TaggedObject.tag_id.in_(tag_ids),
+            # add dashboards that are tagged
+            tagged_objects = (
+                session.query(TaggedObject)
+                .filter(
+                    and_(
+                        TaggedObject.object_type == "dashboard",
+                        TaggedObject.tag_id.in_(tag_ids),
+                    )
                 )
+                .all()
             )
-            .all()
-        )
-        dash_ids = [tagged_object.object_id for tagged_object in tagged_objects]
-        tagged_dashboards = session.query(Dashboard).filter(Dashboard.id.in_(dash_ids))
-        for dashboard in tagged_dashboards:
-            for chart in dashboard.slices:
-                urls.append(get_url(chart))
+            dash_ids = [tagged_object.object_id for tagged_object in tagged_objects]
+            tagged_dashboards = session.query(Dashboard).filter(
+                Dashboard.id.in_(dash_ids)
+            )
+            for dashboard in tagged_dashboards:
+                for chart in dashboard.slices:
+                    payloads.append(get_payload(chart))
 
-        # add charts that are tagged
-        tagged_objects = (
-            session.query(TaggedObject)
-            .filter(
-                and_(
-                    TaggedObject.object_type == "chart",
-                    TaggedObject.tag_id.in_(tag_ids),
+            # add charts that are tagged
+            tagged_objects = (
+                session.query(TaggedObject)
+                .filter(
+                    and_(
+                        TaggedObject.object_type == "chart",
+                        TaggedObject.tag_id.in_(tag_ids),
+                    )
                 )
+                .all()
             )
-            .all()
-        )
-        chart_ids = [tagged_object.object_id for tagged_object in tagged_objects]
-        tagged_charts = session.query(Slice).filter(Slice.id.in_(chart_ids))
-        for chart in tagged_charts:
-            urls.append(get_url(chart))
-
-        return urls
+            chart_ids = [tagged_object.object_id for tagged_object in tagged_objects]
+            tagged_charts = session.query(Slice).filter(Slice.id.in_(chart_ids))
+            for chart in tagged_charts:
+                payloads.append(get_payload(chart))
+        finally:
+            session.close()
+        return payloads
 
 
 strategies = [DummyStrategy, TopNDashboardsStrategy, DashboardTagsStrategy]
 
 
 @celery_app.task(name="fetch_url")
-def fetch_url(url: str, headers: Dict[str, str]) -> Dict[str, str]:
+def fetch_url(data: str, headers: dict[str, str]) -> dict[str, str]:
     """
     Celery job to fetch url
     """
     result = {}
     try:
-        logger.info("Fetching %s", url)
-        req = request.Request(url, headers=headers)
+        baseurl = "{WEBDRIVER_BASEURL}".format(**app.config)
+        url = f"{baseurl}api/v1/chart/warm_up_cache"
+        logger.info("Fetching %s with payload %s", url, data)
+        req = request.Request(
+            url, data=bytes(data, "utf-8"), headers=headers, method="PUT"
+        )
         response = request.urlopen(  # pylint: disable=consider-using-with
             req, timeout=600
         )
-        logger.info("Fetched %s, status code: %s", url, response.code)
+        logger.info(
+            "Fetched %s with payload %s, status code: %s", url, data, response.code
+        )
         if response.code == 200:
-            result = {"success": url, "response": response.read().decode("utf-8")}
+            result = {"success": data, "response": response.read().decode("utf-8")}
         else:
-            result = {"error": url, "status_code": response.code}
-            logger.error("Error fetching %s, status code: %s", url, response.code)
+            result = {"error": data, "status_code": response.code}
+            logger.error(
+                "Error fetching %s with payload %s, status code: %s",
+                url,
+                data,
+                response.code,
+            )
     except URLError as err:
         logger.exception("Error warming up cache!")
-        result = {"error": url, "exception": str(err)}
+        result = {"error": data, "exception": str(err)}
     return result
 
 
 @celery_app.task(name="cache-warmup")
 def cache_warmup(
     strategy_name: str, *args: Any, **kwargs: Any
-) -> Union[Dict[str, List[str]], str]:
+) -> Union[dict[str, list[str]], str]:
     """
     Warm up cache.
 
@@ -270,16 +292,20 @@ def cache_warmup(
 
     user = security_manager.get_user_by_username(app.config["THUMBNAIL_SELENIUM_USER"])
     cookies = MachineAuthProvider.get_auth_cookies(user)
-    headers = {"Cookie": f"session={cookies.get('session', '')}"}
+    headers = {
+        "Cookie": f"session={cookies.get('session', '')}",
+        "Content-Type": "application/json",
+    }
 
-    results: Dict[str, List[str]] = {"scheduled": [], "errors": []}
-    for url in strategy.get_urls():
+    results: dict[str, list[str]] = {"scheduled": [], "errors": []}
+    for payload in strategy.get_payloads():
         try:
-            logger.info("Scheduling %s", url)
-            fetch_url.delay(url, headers)
-            results["scheduled"].append(url)
+            payload = json.dumps(payload)
+            logger.info("Scheduling %s", payload)
+            fetch_url.delay(payload, headers)
+            results["scheduled"].append(payload)
         except SchedulingError:
-            logger.exception("Error scheduling fetch_url: %s", url)
-            results["errors"].append(url)
+            logger.exception("Error scheduling fetch_url for payload: %s", payload)
+            results["errors"].append(payload)
 
     return results
