@@ -17,7 +17,7 @@
 import logging
 from collections import defaultdict
 from functools import wraps
-from typing import Any, Callable, DefaultDict, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, DefaultDict, Optional, Union
 from urllib import parse
 
 import msgpack
@@ -33,7 +33,7 @@ from werkzeug.wrappers.response import Response
 import superset.models.core as models
 from superset import app, dataframe, db, result_set, viz
 from superset.common.db_query_status import QueryStatus
-from superset.datasource.dao import DatasourceDAO
+from superset.daos.datasource import DatasourceDAO
 from superset.errors import ErrorLevel, SupersetError, SupersetErrorType
 from superset.exceptions import (
     CacheLoadError,
@@ -55,13 +55,12 @@ from superset.viz import BaseViz
 logger = logging.getLogger(__name__)
 stats_logger = app.config["STATS_LOGGER"]
 
-
-REJECTED_FORM_DATA_KEYS: List[str] = []
+REJECTED_FORM_DATA_KEYS: list[str] = []
 if not feature_flag_manager.is_feature_enabled("ENABLE_JAVASCRIPT_CONTROLS"):
     REJECTED_FORM_DATA_KEYS = ["js_tooltip", "js_onclick_href", "js_data_mutator"]
 
 
-def sanitize_datasource_data(datasource_data: Dict[str, Any]) -> Dict[str, Any]:
+def sanitize_datasource_data(datasource_data: dict[str, Any]) -> dict[str, Any]:
     if datasource_data:
         datasource_database = datasource_data.get("database")
         if datasource_database:
@@ -70,7 +69,7 @@ def sanitize_datasource_data(datasource_data: Dict[str, Any]) -> Dict[str, Any]:
     return datasource_data
 
 
-def bootstrap_user_data(user: User, include_perms: bool = False) -> Dict[str, Any]:
+def bootstrap_user_data(user: User, include_perms: bool = False) -> dict[str, Any]:
     if user.is_anonymous:
         payload = {}
         user.roles = (security_manager.find_role("Public"),)
@@ -104,7 +103,7 @@ def bootstrap_user_data(user: User, include_perms: bool = False) -> Dict[str, An
 
 def get_permissions(
     user: User,
-) -> Tuple[Dict[str, List[Tuple[str]]], DefaultDict[str, List[str]]]:
+) -> tuple[dict[str, list[tuple[str]]], DefaultDict[str, list[str]]]:
     if not user.roles:
         raise AttributeError("User object does not have roles")
 
@@ -139,7 +138,7 @@ def get_viz(
     return viz_obj
 
 
-def loads_request_json(request_json_data: str) -> Dict[Any, Any]:
+def loads_request_json(request_json_data: str) -> dict[Any, Any]:
     try:
         return json.loads(request_json_data)
     except (TypeError, json.JSONDecodeError):
@@ -149,9 +148,9 @@ def loads_request_json(request_json_data: str) -> Dict[Any, Any]:
 def get_form_data(  # pylint: disable=too-many-locals
     slice_id: Optional[int] = None,
     use_slice_data: bool = False,
-    initial_form_data: Optional[Dict[str, Any]] = None,
-) -> Tuple[Dict[str, Any], Optional[Slice]]:
-    form_data: Dict[str, Any] = initial_form_data or {}
+    initial_form_data: Optional[dict[str, Any]] = None,
+) -> tuple[dict[str, Any], Optional[Slice]]:
+    form_data: dict[str, Any] = initial_form_data or {}
 
     if has_request_context():
         # chart data API requests are JSON
@@ -223,7 +222,7 @@ def get_form_data(  # pylint: disable=too-many-locals
     return form_data, slc
 
 
-def add_sqllab_custom_filters(form_data: Dict[Any, Any]) -> Any:
+def add_sqllab_custom_filters(form_data: dict[Any, Any]) -> Any:
     """
     SQLLab can include a "filters" attribute in the templateParams.
     The filters attribute is a list of filters to include in the
@@ -245,7 +244,7 @@ def add_sqllab_custom_filters(form_data: Dict[Any, Any]) -> Any:
 
 def get_datasource_info(
     datasource_id: Optional[int], datasource_type: Optional[str], form_data: FormData
-) -> Tuple[int, Optional[str]]:
+) -> tuple[int, Optional[str]]:
     """
     Compatibility layer for handling of datasource info
 
@@ -255,15 +254,14 @@ def get_datasource_info(
     This function allows supporting both without duplicating code
 
     :param datasource_id: The datasource ID
-    :param datasource_type: The datasource type, i.e., 'druid' or 'table'
+    :param datasource_type: The datasource type
     :param form_data: The URL form data
     :returns: The datasource ID and type
     :raises SupersetException: If the datasource no longer exists
     """
 
-    datasource = form_data.get("datasource", "")
-
-    if "__" in datasource:
+    # pylint: disable=superfluous-parens
+    if "__" in (datasource := form_data.get("datasource", "")):
         datasource_id, datasource_type = datasource.split("__")
         # The case where the datasource has been deleted
         if datasource_id == "None":
@@ -279,8 +277,8 @@ def get_datasource_info(
 
 
 def apply_display_max_row_limit(
-    sql_results: Dict[str, Any], rows: Optional[int] = None
-) -> Dict[str, Any]:
+    sql_results: dict[str, Any], rows: Optional[int] = None
+) -> dict[str, Any]:
     """
     Given a `sql_results` nested structure, applies a limit to the number of rows
 
@@ -313,7 +311,7 @@ CONTAINER_TYPES = ["COLUMN", "GRID", "TABS", "TAB", "ROW"]
 
 def get_dashboard_extra_filters(
     slice_id: int, dashboard_id: int
-) -> List[Dict[str, Any]]:
+) -> list[dict[str, Any]]:
     session = db.session()
     dashboard = session.query(Dashboard).filter_by(id=dashboard_id).one_or_none()
 
@@ -350,11 +348,11 @@ def get_dashboard_extra_filters(
 
 
 def build_extra_filters(  # pylint: disable=too-many-locals,too-many-nested-blocks
-    layout: Dict[str, Dict[str, Any]],
-    filter_scopes: Dict[str, Dict[str, Any]],
-    default_filters: Dict[str, Dict[str, List[Any]]],
+    layout: dict[str, dict[str, Any]],
+    filter_scopes: dict[str, dict[str, Any]],
+    default_filters: dict[str, dict[str, list[Any]]],
     slice_id: int,
-) -> List[Dict[str, Any]]:
+) -> list[dict[str, Any]]:
     extra_filters = []
 
     # do not apply filters if chart is not in filter's scope or chart is immune to the
@@ -362,7 +360,7 @@ def build_extra_filters(  # pylint: disable=too-many-locals,too-many-nested-bloc
     for filter_id, columns in default_filters.items():
         filter_slice = db.session.query(Slice).filter_by(id=filter_id).one_or_none()
 
-        filter_configs: List[Dict[str, Any]] = []
+        filter_configs: list[dict[str, Any]] = []
         if filter_slice:
             filter_configs = (
                 json.loads(filter_slice.params or "{}").get("filter_configs") or []
@@ -405,7 +403,7 @@ def build_extra_filters(  # pylint: disable=too-many-locals,too-many-nested-bloc
 
 
 def is_slice_in_container(
-    layout: Dict[str, Dict[str, Any]], container_id: str, slice_id: int
+    layout: dict[str, dict[str, Any]], container_id: str, slice_id: int
 ) -> bool:
     if container_id == "ROOT_ID":
         return True
@@ -462,7 +460,7 @@ def check_datasource_perms(
     _self: Any,
     datasource_type: Optional[str] = None,
     datasource_id: Optional[int] = None,
-    **kwargs: Any
+    **kwargs: Any,
 ) -> None:
     """
     Check if user can access a cached response from explore_json.
@@ -470,7 +468,7 @@ def check_datasource_perms(
     This function takes `self` since it must have the same signature as the
     the decorated method.
 
-    :param datasource_type: The datasource type, i.e., 'druid' or 'table'
+    :param datasource_type: The datasource type
     :param datasource_id: The datasource ID
     :raises SupersetSecurityException: If the user cannot access the resource
     """
@@ -518,42 +516,9 @@ def check_datasource_perms(
     viz_obj.raise_for_access()
 
 
-def check_slice_perms(_self: Any, slice_id: int) -> None:
-    """
-    Check if user can access a cached response from slice_json.
-
-    This function takes `self` since it must have the same signature as the
-    the decorated method.
-
-    :param slice_id: The slice ID
-    :raises SupersetSecurityException: If the user cannot access the resource
-    """
-
-    form_data, slc = get_form_data(slice_id, use_slice_data=True)
-
-    if slc and slc.datasource:
-        try:
-            viz_obj = get_viz(
-                datasource_type=slc.datasource.type,
-                datasource_id=slc.datasource.id,
-                form_data=form_data,
-                force=False,
-            )
-        except NoResultFound as ex:
-            raise SupersetSecurityException(
-                SupersetError(
-                    error_type=SupersetErrorType.UNKNOWN_DATASOURCE_TYPE_ERROR,
-                    level=ErrorLevel.ERROR,
-                    message="Could not find viz object",
-                )
-            ) from ex
-
-        viz_obj.raise_for_access()
-
-
 def _deserialize_results_payload(
     payload: Union[bytes, str], query: Query, use_msgpack: Optional[bool] = False
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     logger.debug("Deserializing from msgpack: %r", use_msgpack)
     if use_msgpack:
         with stats_timing(
@@ -563,13 +528,18 @@ def _deserialize_results_payload(
 
         with stats_timing("sqllab.query.results_backend_pa_deserialize", stats_logger):
             try:
-                pa_table = pa.deserialize(ds_payload["data"])
+                reader = pa.BufferReader(ds_payload["data"])
+                pa_table = pa.ipc.open_stream(reader).read_all()
             except pa.ArrowSerializationError as ex:
                 raise SerializationError("Unable to deserialize table") from ex
 
         df = result_set.SupersetResultSet.convert_table_to_df(pa_table)
         ds_payload["data"] = dataframe.df_to_records(df) or []
 
+        for column in ds_payload["selected_columns"]:
+            if "name" in column:
+                column["column_name"] = column.get("name")
+
         db_engine_spec = query.database.db_engine_spec
         all_columns, data, expanded_columns = db_engine_spec.expand_data(
             ds_payload["selected_columns"], ds_payload["data"]
