@@ -15,11 +15,10 @@
 # specific language governing permissions and limitations
 # under the License.
 # isort:skip_file
-from datetime import date, datetime, timezone
+from datetime import datetime
 import logging
 from math import nan
 from unittest.mock import Mock, patch
-from typing import Any, Dict, List, Set
 
 import numpy as np
 import pandas as pd
@@ -46,7 +45,7 @@ class TestBaseViz(SupersetTestCase):
             viz.BaseViz(datasource, form_data)
 
     def test_process_metrics(self):
-        # test TableViz metrics in correct order
+        # test TimeTableViz metrics in correct order
         form_data = {
             "url_params": {},
             "row_limit": 500,
@@ -56,7 +55,7 @@ class TestBaseViz(SupersetTestCase):
             "granularity_sqla": "year",
             "page_length": 0,
             "all_columns": [],
-            "viz_type": "table",
+            "viz_type": "time_table",
             "since": "2014-01-01",
             "until": "2014-01-02",
             "metrics": ["sum__SP_POP_TOTL", "SUM(SE_PRM_NENR_MA)", "SUM(SP_URB_TOTL)"],
@@ -178,273 +177,6 @@ class TestBaseViz(SupersetTestCase):
         app.config["DATA_CACHE_CONFIG"]["CACHE_DEFAULT_TIMEOUT"] = data_cache_timeout
 
 
-class TestTableViz(SupersetTestCase):
-    def test_get_data_applies_percentage(self):
-        form_data = {
-            "groupby": ["groupA", "groupB"],
-            "metrics": [
-                {
-                    "expressionType": "SIMPLE",
-                    "aggregate": "SUM",
-                    "label": "SUM(value1)",
-                    "column": {"column_name": "value1", "type": "DOUBLE"},
-                },
-                "count",
-                "avg__C",
-            ],
-            "percent_metrics": [
-                {
-                    "expressionType": "SIMPLE",
-                    "aggregate": "SUM",
-                    "label": "SUM(value1)",
-                    "column": {"column_name": "value1", "type": "DOUBLE"},
-                },
-                "avg__B",
-            ],
-        }
-        datasource = self.get_datasource_mock()
-
-        df = pd.DataFrame(
-            {
-                "SUM(value1)": [15, 20, 25, 40],
-                "avg__B": [10, 20, 5, 15],
-                "avg__C": [11, 22, 33, 44],
-                "count": [6, 7, 8, 9],
-                "groupA": ["A", "B", "C", "C"],
-                "groupB": ["x", "x", "y", "z"],
-            }
-        )
-
-        test_viz = viz.TableViz(datasource, form_data)
-        data = test_viz.get_data(df)
-        # Check method correctly transforms data and computes percents
-        self.assertEqual(
-            [
-                "groupA",
-                "groupB",
-                "SUM(value1)",
-                "count",
-                "avg__C",
-                "%SUM(value1)",
-                "%avg__B",
-            ],
-            list(data["columns"]),
-        )
-        expected = [
-            {
-                "groupA": "A",
-                "groupB": "x",
-                "SUM(value1)": 15,
-                "count": 6,
-                "avg__C": 11,
-                "%SUM(value1)": 0.15,
-                "%avg__B": 0.2,
-            },
-            {
-                "groupA": "B",
-                "groupB": "x",
-                "SUM(value1)": 20,
-                "count": 7,
-                "avg__C": 22,
-                "%SUM(value1)": 0.2,
-                "%avg__B": 0.4,
-            },
-            {
-                "groupA": "C",
-                "groupB": "y",
-                "SUM(value1)": 25,
-                "count": 8,
-                "avg__C": 33,
-                "%SUM(value1)": 0.25,
-                "%avg__B": 0.1,
-            },
-            {
-                "groupA": "C",
-                "groupB": "z",
-                "SUM(value1)": 40,
-                "count": 9,
-                "avg__C": 44,
-                "%SUM(value1)": 0.4,
-                "%avg__B": 0.3,
-            },
-        ]
-        self.assertEqual(expected, data["records"])
-
-    def test_parse_adhoc_filters(self):
-        form_data = {
-            "metrics": [
-                {
-                    "expressionType": "SIMPLE",
-                    "aggregate": "SUM",
-                    "label": "SUM(value1)",
-                    "column": {"column_name": "value1", "type": "DOUBLE"},
-                }
-            ],
-            "adhoc_filters": [
-                {
-                    "expressionType": "SIMPLE",
-                    "clause": "WHERE",
-                    "subject": "value2",
-                    "operator": ">",
-                    "comparator": "100",
-                },
-                {
-                    "expressionType": "SQL",
-                    "clause": "HAVING",
-                    "sqlExpression": "SUM(value1) > 5",
-                },
-                {
-                    "expressionType": "SQL",
-                    "clause": "WHERE",
-                    "sqlExpression": "value3 in ('North America')",
-                },
-            ],
-        }
-        datasource = self.get_datasource_mock()
-        test_viz = viz.TableViz(datasource, form_data)
-        query_obj = test_viz.query_obj()
-        self.assertEqual(
-            [{"col": "value2", "val": "100", "op": ">"}], query_obj["filter"]
-        )
-        self.assertEqual("(value3 in ('North America'))", query_obj["extras"]["where"])
-        self.assertEqual("(SUM(value1) > 5)", query_obj["extras"]["having"])
-
-    def test_adhoc_filters_overwrite_legacy_filters(self):
-        form_data = {
-            "metrics": [
-                {
-                    "expressionType": "SIMPLE",
-                    "aggregate": "SUM",
-                    "label": "SUM(value1)",
-                    "column": {"column_name": "value1", "type": "DOUBLE"},
-                }
-            ],
-            "adhoc_filters": [
-                {
-                    "expressionType": "SIMPLE",
-                    "clause": "WHERE",
-                    "subject": "value2",
-                    "operator": ">",
-                    "comparator": "100",
-                },
-                {
-                    "expressionType": "SQL",
-                    "clause": "WHERE",
-                    "sqlExpression": "value3 in ('North America')",
-                },
-            ],
-            "having": "SUM(value1) > 5",
-        }
-        datasource = self.get_datasource_mock()
-        test_viz = viz.TableViz(datasource, form_data)
-        query_obj = test_viz.query_obj()
-        self.assertEqual(
-            [{"col": "value2", "val": "100", "op": ">"}], query_obj["filter"]
-        )
-        self.assertEqual("(value3 in ('North America'))", query_obj["extras"]["where"])
-        self.assertEqual("", query_obj["extras"]["having"])
-
-    def test_query_obj_merges_percent_metrics(self):
-        datasource = self.get_datasource_mock()
-        form_data = {
-            "metrics": ["sum__A", "count", "avg__C"],
-            "percent_metrics": ["sum__A", "avg__B", "max__Y"],
-        }
-        test_viz = viz.TableViz(datasource, form_data)
-        query_obj = test_viz.query_obj()
-        self.assertEqual(
-            ["sum__A", "count", "avg__C", "avg__B", "max__Y"], query_obj["metrics"]
-        )
-
-    def test_query_obj_throws_columns_and_metrics(self):
-        datasource = self.get_datasource_mock()
-        form_data = {"all_columns": ["A", "B"], "metrics": ["x", "y"]}
-        with self.assertRaises(Exception):
-            test_viz = viz.TableViz(datasource, form_data)
-            test_viz.query_obj()
-        del form_data["metrics"]
-        form_data["groupby"] = ["B", "C"]
-        with self.assertRaises(Exception):
-            test_viz = viz.TableViz(datasource, form_data)
-            test_viz.query_obj()
-
-    @patch("superset.viz.BaseViz.query_obj")
-    def test_query_obj_merges_all_columns(self, super_query_obj):
-        datasource = self.get_datasource_mock()
-        form_data = {
-            "all_columns": ["colA", "colB", "colC"],
-            "order_by_cols": ['["colA", "colB"]', '["colC"]'],
-        }
-        super_query_obj.return_value = {
-            "columns": ["colD", "colC"],
-            "groupby": ["colA", "colB"],
-        }
-        test_viz = viz.TableViz(datasource, form_data)
-        query_obj = test_viz.query_obj()
-        self.assertEqual(form_data["all_columns"], query_obj["columns"])
-        self.assertEqual([], query_obj["groupby"])
-        self.assertEqual([["colA", "colB"], ["colC"]], query_obj["orderby"])
-
-    def test_query_obj_uses_sortby(self):
-        datasource = self.get_datasource_mock()
-        form_data = {
-            "metrics": ["colA", "colB"],
-            "order_desc": False,
-        }
-
-        def run_test(metric):
-            form_data["timeseries_limit_metric"] = metric
-            test_viz = viz.TableViz(datasource, form_data)
-            query_obj = test_viz.query_obj()
-            self.assertEqual(["colA", "colB", metric], query_obj["metrics"])
-            self.assertEqual([(metric, True)], query_obj["orderby"])
-
-        run_test("simple_metric")
-        run_test(
-            {
-                "label": "adhoc_metric",
-                "expressionType": "SIMPLE",
-                "aggregate": "SUM",
-                "column": {
-                    "column_name": "sort_column",
-                },
-            }
-        )
-
-    def test_should_be_timeseries_raises_when_no_granularity(self):
-        datasource = self.get_datasource_mock()
-        form_data = {"include_time": True}
-        with self.assertRaises(Exception):
-            test_viz = viz.TableViz(datasource, form_data)
-            test_viz.should_be_timeseries()
-
-    def test_adhoc_metric_with_sortby(self):
-        metrics = [
-            {
-                "expressionType": "SIMPLE",
-                "aggregate": "SUM",
-                "label": "sum_value",
-                "column": {"column_name": "value1", "type": "DOUBLE"},
-            }
-        ]
-        form_data = {
-            "metrics": metrics,
-            "timeseries_limit_metric": {
-                "expressionType": "SIMPLE",
-                "aggregate": "SUM",
-                "label": "SUM(value1)",
-                "column": {"column_name": "value1", "type": "DOUBLE"},
-            },
-            "order_desc": False,
-        }
-
-        df = pd.DataFrame({"SUM(value1)": [15], "sum_value": [15]})
-        datasource = self.get_datasource_mock()
-        test_viz = viz.TableViz(datasource, form_data)
-        data = test_viz.get_data(df)
-        self.assertEqual(["sum_value"], data["columns"])
-
-
 class TestDistBarViz(SupersetTestCase):
     def test_groupby_nulls(self):
         form_data = {
@@ -1009,7 +741,7 @@ class TestTimeSeriesTableViz(SupersetTestCase):
         test_viz = viz.TimeTableViz(datasource, form_data)
         data = test_viz.get_data(df)
         # Check method correctly transforms data
-        self.assertEqual(set(["count", "sum__A"]), set(data["columns"]))
+        self.assertEqual({"count", "sum__A"}, set(data["columns"]))
         time_format = "%Y-%m-%d %H:%M:%S"
         expected = {
             t1.strftime(time_format): {"sum__A": 15, "count": 6},
@@ -1030,7 +762,7 @@ class TestTimeSeriesTableViz(SupersetTestCase):
         test_viz = viz.TimeTableViz(datasource, form_data)
         data = test_viz.get_data(df)
         # Check method correctly transforms data
-        self.assertEqual(set(["a1", "a2", "a3"]), set(data["columns"]))
+        self.assertEqual({"a1", "a2", "a3"}, set(data["columns"]))
         time_format = "%Y-%m-%d %H:%M:%S"
         expected = {
             t1.strftime(time_format): {"a1": 15, "a2": 20, "a3": 25},
@@ -1312,7 +1044,7 @@ class TestTimeSeriesViz(SupersetTestCase):
             data={"y": [1.0, 2.0, 3.0, 4.0]},
         )
         self.assertEqual(
-            viz.BigNumberViz(
+            viz.NVD3TimeSeriesViz(
                 datasource,
                 {
                     "metrics": ["y"],
@@ -1326,7 +1058,7 @@ class TestTimeSeriesViz(SupersetTestCase):
             [1.0, 3.0, 6.0, 10.0],
         )
         self.assertEqual(
-            viz.BigNumberViz(
+            viz.NVD3TimeSeriesViz(
                 datasource,
                 {
                     "metrics": ["y"],
@@ -1340,7 +1072,7 @@ class TestTimeSeriesViz(SupersetTestCase):
             [1.0, 3.0, 5.0, 7.0],
         )
         self.assertEqual(
-            viz.BigNumberViz(
+            viz.NVD3TimeSeriesViz(
                 datasource,
                 {
                     "metrics": ["y"],
@@ -1362,7 +1094,7 @@ class TestTimeSeriesViz(SupersetTestCase):
             ),
             data={"y": [1.0, 2.0, 3.0, 4.0]},
         )
-        test_viz = viz.BigNumberViz(
+        test_viz = viz.NVD3TimeSeriesViz(
             datasource,
             {
                 "metrics": ["y"],
@@ -1375,104 +1107,6 @@ class TestTimeSeriesViz(SupersetTestCase):
             test_viz.apply_rolling(df)
 
 
-class TestBigNumberViz(SupersetTestCase):
-    def test_get_data(self):
-        datasource = self.get_datasource_mock()
-        df = pd.DataFrame(
-            data={
-                DTTM_ALIAS: pd.to_datetime(
-                    ["2019-01-01", "2019-01-02", "2019-01-05", "2019-01-07"]
-                ),
-                "y": [1.0, 2.0, 3.0, 4.0],
-            }
-        )
-        data = viz.BigNumberViz(datasource, {"metrics": ["y"]}).get_data(df)
-        self.assertEqual(data[2], {DTTM_ALIAS: pd.Timestamp("2019-01-05"), "y": 3})
-
-    def test_get_data_with_none(self):
-        datasource = self.get_datasource_mock()
-        df = pd.DataFrame(
-            data={
-                DTTM_ALIAS: pd.to_datetime(
-                    ["2019-01-01", "2019-01-02", "2019-01-05", "2019-01-07"]
-                ),
-                "y": [1.0, 2.0, None, 4.0],
-            }
-        )
-        data = viz.BigNumberViz(datasource, {"metrics": ["y"]}).get_data(df)
-        assert np.isnan(data[2]["y"])
-
-
-class TestPivotTableViz(SupersetTestCase):
-    df = pd.DataFrame(
-        data={
-            "intcol": [1, 2, 3, None],
-            "floatcol": [0.1, 0.2, 0.3, None],
-            "strcol": ["a", "b", "c", None],
-        }
-    )
-
-    def test_get_aggfunc_numeric(self):
-        # is a sum function
-        func = viz.PivotTableViz.get_aggfunc("intcol", self.df, {})
-        assert hasattr(func, "__call__")
-        assert func(self.df["intcol"]) == 6
-
-        assert (
-            viz.PivotTableViz.get_aggfunc("intcol", self.df, {"pandas_aggfunc": "min"})
-            == "min"
-        )
-        assert (
-            viz.PivotTableViz.get_aggfunc(
-                "floatcol", self.df, {"pandas_aggfunc": "max"}
-            )
-            == "max"
-        )
-
-    def test_get_aggfunc_non_numeric(self):
-        assert viz.PivotTableViz.get_aggfunc("strcol", self.df, {}) == "max"
-        assert (
-            viz.PivotTableViz.get_aggfunc("strcol", self.df, {"pandas_aggfunc": "sum"})
-            == "max"
-        )
-        assert (
-            viz.PivotTableViz.get_aggfunc("strcol", self.df, {"pandas_aggfunc": "min"})
-            == "min"
-        )
-
-    def test_format_datetime_from_pd_timestamp(self):
-        tstamp = pd.Timestamp(datetime(2020, 9, 3, tzinfo=timezone.utc))
-        assert (
-            viz.PivotTableViz._format_datetime(tstamp) == "__timestamp:1599091200000.0"
-        )
-
-    def test_format_datetime_from_datetime(self):
-        tstamp = datetime(2020, 9, 3, tzinfo=timezone.utc)
-        assert (
-            viz.PivotTableViz._format_datetime(tstamp) == "__timestamp:1599091200000.0"
-        )
-
-    def test_format_datetime_from_date(self):
-        tstamp = date(2020, 9, 3)
-        assert (
-            viz.PivotTableViz._format_datetime(tstamp) == "__timestamp:1599091200000.0"
-        )
-
-    def test_format_datetime_from_string(self):
-        tstamp = "2020-09-03T00:00:00"
-        assert (
-            viz.PivotTableViz._format_datetime(tstamp) == "__timestamp:1599091200000.0"
-        )
-
-    def test_format_datetime_from_invalid_string(self):
-        tstamp = "abracadabra"
-        assert viz.PivotTableViz._format_datetime(tstamp) == tstamp
-
-    def test_format_datetime_from_int(self):
-        assert viz.PivotTableViz._format_datetime(123) == 123
-        assert viz.PivotTableViz._format_datetime(123.0) == 123.0
-
-
 class TestFilterBoxViz(SupersetTestCase):
     def test_get_data(self):
         form_data = {
