@@ -14,9 +14,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-import json
 from datetime import datetime, timedelta
-from typing import Any, Iterator
+from typing import Any
 
 import pytest
 from pytest_mock import MockFixture
@@ -52,7 +51,7 @@ def test_query_dao_save_metadata(session: Session) -> None:
     session.add(db)
     session.add(query_obj)
 
-    from superset.queries.dao import QueryDAO
+    from superset.daos.query import QueryDAO
 
     query = session.query(Query).one()
     QueryDAO.save_metadata(query=query, payload={"columns": []})
@@ -106,7 +105,7 @@ def test_query_dao_get_queries_changed_after(session: Session) -> None:
     session.add(old_query_obj)
     session.add(updated_query_obj)
 
-    from superset.queries.dao import QueryDAO
+    from superset.daos.query import QueryDAO
 
     timestamp = datetime.timestamp(now - timedelta(days=2)) * 1000
     result = QueryDAO.get_queries_changed_after(timestamp)
@@ -147,7 +146,7 @@ def test_query_dao_stop_query_not_found(
 
     mocker.patch("superset.sql_lab.cancel_query", return_value=False)
 
-    from superset.queries.dao import QueryDAO
+    from superset.daos.query import QueryDAO
 
     with pytest.raises(QueryNotFoundException):
         QueryDAO.stop_query("foo2")
@@ -187,7 +186,7 @@ def test_query_dao_stop_query_not_running(
     session.add(db)
     session.add(query_obj)
 
-    from superset.queries.dao import QueryDAO
+    from superset.daos.query import QueryDAO
 
     QueryDAO.stop_query(query_obj.client_id)
     query = session.query(Query).one()
@@ -227,7 +226,7 @@ def test_query_dao_stop_query_failed(
 
     mocker.patch("superset.sql_lab.cancel_query", return_value=False)
 
-    from superset.queries.dao import QueryDAO
+    from superset.daos.query import QueryDAO
 
     with pytest.raises(SupersetCancelQueryException):
         QueryDAO.stop_query(query_obj.client_id)
@@ -267,7 +266,7 @@ def test_query_dao_stop_query(mocker: MockFixture, app: Any, session: Session) -
 
     mocker.patch("superset.sql_lab.cancel_query", return_value=True)
 
-    from superset.queries.dao import QueryDAO
+    from superset.daos.query import QueryDAO
 
     QueryDAO.stop_query(query_obj.client_id)
     query = session.query(Query).one()
